;; Generated package description from mode: lisp-data; .el  -*- doc-view-followno-byte-compile: t -*-
(define-package "doc-view-follow" "0.3.0.20250414.142827" "Synchronize windows showing the same document" '((emacs "29.1")) :commit "e9d80f5db7549ebddb311f294c6f7a826cc02c9a" :authors '(("Paul D. Nelson" . "ultrono@gmail.com")) :maintainer '("Paul D. Nelson" . "ultrono@gmail.com") :keywords '("convenience") :url "https://github.com/ultronozm/doc-view-follow.el")
